==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/change/vo/ChangeconsdrawbudgettotaldetailVO.java <==
package com.ejianc.business.change.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 施工预算图汇总表变更子表
 * 
 * @author generator
 * 
 */
public class ChangeconsdrawbudgettotaldetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long changeMid; // 变更主表id
    private java.lang.String sort; // 序号
    private java.lang.String code; // 编码
    private java.lang.String section; // 区段
    private java.lang.String projectUnitName; // 单位工程名称
    private java.math.BigDecimal projectCost; // 项目造价
    private java.math.BigDecimal unitLaborCost; // 人工费(单价)
    private java.math.BigDecimal unitMaterialCost; // 材料费(单价)
    private java.math.BigDecimal unitMachineryCost; // 机械费(单价)
    private java.math.BigDecimal unitBusinessManagerCost; // 企业管理费(单价)
    private java.math.BigDecimal unitProfit; // 利润(单价)
    private java.math.BigDecimal itemsSubTotal; // 分部分项合计
    private java.math.BigDecimal fees; // 规费
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal unilateralMeasuresCost; // 单方措施项目合计
    private java.math.BigDecimal garbageConsumption; // 施工垃圾场外晕和消纳费
    private java.math.BigDecimal otherItems; // 其他项目
    private java.math.BigDecimal costPercent; // 造价占比
    private java.math.BigDecimal projectScale; // 工程规模
    private java.lang.String unitCost; // 单位造价
    private java.lang.String billCode; // 单据编码
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    

    /**
     * 变更主表id
     */
    public java.lang.Long getChangeMid() {
        return changeMid;
    }

    /**
     * 变更主表id
     */
    public void setChangeMid(java.lang.Long changeMid) {
        this.changeMid = changeMid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 单位工程名称
     */
    public java.lang.String getProjectUnitName() {
        return projectUnitName;
    }

    /**
     * 单位工程名称
     */
    public void setProjectUnitName(java.lang.String projectUnitName) {
        this.projectUnitName = projectUnitName;
    }
    /**
     * 项目造价
     */
    public java.math.BigDecimal getProjectCost() {
        return projectCost;
    }

    /**
     * 项目造价
     */
    public void setProjectCost(java.math.BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    /**
     * 人工费(单价)
     */
    public java.math.BigDecimal getUnitLaborCost() {
        return unitLaborCost;
    }

    /**
     * 人工费(单价)
     */
    public void setUnitLaborCost(java.math.BigDecimal unitLaborCost) {
        this.unitLaborCost = unitLaborCost;
    }
    /**
     * 材料费(单价)
     */
    public java.math.BigDecimal getUnitMaterialCost() {
        return unitMaterialCost;
    }

    /**
     * 材料费(单价)
     */
    public void setUnitMaterialCost(java.math.BigDecimal unitMaterialCost) {
        this.unitMaterialCost = unitMaterialCost;
    }
    /**
     * 机械费(单价)
     */
    public java.math.BigDecimal getUnitMachineryCost() {
        return unitMachineryCost;
    }

    /**
     * 机械费(单价)
     */
    public void setUnitMachineryCost(java.math.BigDecimal unitMachineryCost) {
        this.unitMachineryCost = unitMachineryCost;
    }
    /**
     * 企业管理费(单价)
     */
    public java.math.BigDecimal getUnitBusinessManagerCost() {
        return unitBusinessManagerCost;
    }

    /**
     * 企业管理费(单价)
     */
    public void setUnitBusinessManagerCost(java.math.BigDecimal unitBusinessManagerCost) {
        this.unitBusinessManagerCost = unitBusinessManagerCost;
    }
    /**
     * 利润(单价)
     */
    public java.math.BigDecimal getUnitProfit() {
        return unitProfit;
    }

    /**
     * 利润(单价)
     */
    public void setUnitProfit(java.math.BigDecimal unitProfit) {
        this.unitProfit = unitProfit;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getItemsSubTotal() {
        return itemsSubTotal;
    }

    /**
     * 分部分项合计
     */
    public void setItemsSubTotal(java.math.BigDecimal itemsSubTotal) {
        this.itemsSubTotal = itemsSubTotal;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFees() {
        return fees;
    }

    /**
     * 规费
     */
    public void setFees(java.math.BigDecimal fees) {
        this.fees = fees;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 单方措施项目合计
     */
    public java.math.BigDecimal getUnilateralMeasuresCost() {
        return unilateralMeasuresCost;
    }

    /**
     * 单方措施项目合计
     */
    public void setUnilateralMeasuresCost(java.math.BigDecimal unilateralMeasuresCost) {
        this.unilateralMeasuresCost = unilateralMeasuresCost;
    }
    /**
     * 施工垃圾场外晕和消纳费
     */
    public java.math.BigDecimal getGarbageConsumption() {
        return garbageConsumption;
    }

    /**
     * 施工垃圾场外晕和消纳费
     */
    public void setGarbageConsumption(java.math.BigDecimal garbageConsumption) {
        this.garbageConsumption = garbageConsumption;
    }
    /**
     * 其他项目
     */
    public java.math.BigDecimal getOtherItems() {
        return otherItems;
    }

    /**
     * 其他项目
     */
    public void setOtherItems(java.math.BigDecimal otherItems) {
        this.otherItems = otherItems;
    }
    /**
     * 造价占比
     */
    public java.math.BigDecimal getCostPercent() {
        return costPercent;
    }

    /**
     * 造价占比
     */
    public void setCostPercent(java.math.BigDecimal costPercent) {
        this.costPercent = costPercent;
    }
    /**
     * 工程规模
     */
    public java.math.BigDecimal getProjectScale() {
        return projectScale;
    }

    /**
     * 工程规模
     */
    public void setProjectScale(java.math.BigDecimal projectScale) {
        this.projectScale = projectScale;
    }
    /**
     * 单位造价
     */
    public java.lang.String getUnitCost() {
        return unitCost;
    }

    /**
     * 单位造价
     */
    public void setUnitCost(java.lang.String unitCost) {
        this.unitCost = unitCost;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220407.084509-69-sources.jar: com/ejianc/business/change/vo/ChangeconsdrawbudgettotaldetailVO.java <==
package com.ejianc.business.change.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 施工预算图汇总表变更子表
 * 
 * @author generator
 * 
 */
public class ChangeconsdrawbudgettotaldetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long changeMid; // 变更主表id
    private java.lang.Long originalId; // 原始单据id（施工图预算汇总子表）
    private java.lang.String sort; // 序号
    private java.lang.String code; // 编码
    private java.lang.String section; // 区段
    private java.lang.String subitemCode; // 编码
    private java.lang.String projectUnitName; // 单位工程名称
    private java.math.BigDecimal projectCost; // 项目造价
    private java.math.BigDecimal unitLaborCost; // 人工费(单价)
    private java.math.BigDecimal unitMaterialCost; // 材料费(单价)
    private java.math.BigDecimal unitMachineryCost; // 机械费(单价)
    private java.math.BigDecimal unitBusinessManagerCost; // 企业管理费(单价)
    private java.math.BigDecimal unitProfit; // 利润(单价)
    private java.math.BigDecimal itemsSubTotal; // 分部分项合计
    private java.math.BigDecimal fees; // 规费
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal unilateralMeasuresCost; // 单方措施项目合计
    private java.math.BigDecimal garbageConsumption; // 施工垃圾场外晕和消纳费
    private java.math.BigDecimal otherItems; // 其他项目
    private java.math.BigDecimal costPercent; // 造价占比
    private java.math.BigDecimal projectScale; // 工程规模
    private java.math.BigDecimal unitCost; // 单位造价
    private java.lang.String billCode; // 单据编码
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String tid;
    private java.lang.String tpid;
    private String innercode; // 内码

    private String errorMsg; // 导入错误信息

    private List<ChangeconsdrawbudgettotaldetailVO> children = new ArrayList<>();
    public List<ChangeconsdrawbudgettotaldetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<ChangeconsdrawbudgettotaldetailVO> children) {
        this.children = children;
    }
    

    /**
     * 变更主表id
     */
    public java.lang.Long getChangeMid() {
        return changeMid;
    }

    /**
     * 变更主表id
     */
    public void setChangeMid(java.lang.Long changeMid) {
        this.changeMid = changeMid;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }

    public String getSubitemCode() {
        return subitemCode;
    }

    public void setSubitemCode(String subitemCode) {
        this.subitemCode = subitemCode;
    }

    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 单位工程名称
     */
    public java.lang.String getProjectUnitName() {
        return projectUnitName;
    }

    /**
     * 单位工程名称
     */
    public void setProjectUnitName(java.lang.String projectUnitName) {
        this.projectUnitName = projectUnitName;
    }
    /**
     * 项目造价
     */
    public java.math.BigDecimal getProjectCost() {
        return projectCost;
    }

    /**
     * 项目造价
     */
    public void setProjectCost(java.math.BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    /**
     * 人工费(单价)
     */
    public java.math.BigDecimal getUnitLaborCost() {
        return unitLaborCost;
    }

    /**
     * 人工费(单价)
     */
    public void setUnitLaborCost(java.math.BigDecimal unitLaborCost) {
        this.unitLaborCost = unitLaborCost;
    }
    /**
     * 材料费(单价)
     */
    public java.math.BigDecimal getUnitMaterialCost() {
        return unitMaterialCost;
    }

    /**
     * 材料费(单价)
     */
    public void setUnitMaterialCost(java.math.BigDecimal unitMaterialCost) {
        this.unitMaterialCost = unitMaterialCost;
    }
    /**
     * 机械费(单价)
     */
    public java.math.BigDecimal getUnitMachineryCost() {
        return unitMachineryCost;
    }

    /**
     * 机械费(单价)
     */
    public void setUnitMachineryCost(java.math.BigDecimal unitMachineryCost) {
        this.unitMachineryCost = unitMachineryCost;
    }
    /**
     * 企业管理费(单价)
     */
    public java.math.BigDecimal getUnitBusinessManagerCost() {
        return unitBusinessManagerCost;
    }

    /**
     * 企业管理费(单价)
     */
    public void setUnitBusinessManagerCost(java.math.BigDecimal unitBusinessManagerCost) {
        this.unitBusinessManagerCost = unitBusinessManagerCost;
    }
    /**
     * 利润(单价)
     */
    public java.math.BigDecimal getUnitProfit() {
        return unitProfit;
    }

    /**
     * 利润(单价)
     */
    public void setUnitProfit(java.math.BigDecimal unitProfit) {
        this.unitProfit = unitProfit;
    }
    /**
     * 分部分项合计
     */
    public java.math.BigDecimal getItemsSubTotal() {
        return itemsSubTotal;
    }

    /**
     * 分部分项合计
     */
    public void setItemsSubTotal(java.math.BigDecimal itemsSubTotal) {
        this.itemsSubTotal = itemsSubTotal;
    }
    /**
     * 规费
     */
    public java.math.BigDecimal getFees() {
        return fees;
    }

    /**
     * 规费
     */
    public void setFees(java.math.BigDecimal fees) {
        this.fees = fees;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 单方措施项目合计
     */
    public java.math.BigDecimal getUnilateralMeasuresCost() {
        return unilateralMeasuresCost;
    }

    /**
     * 单方措施项目合计
     */
    public void setUnilateralMeasuresCost(java.math.BigDecimal unilateralMeasuresCost) {
        this.unilateralMeasuresCost = unilateralMeasuresCost;
    }
    /**
     * 施工垃圾场外晕和消纳费
     */
    public java.math.BigDecimal getGarbageConsumption() {
        return garbageConsumption;
    }

    /**
     * 施工垃圾场外晕和消纳费
     */
    public void setGarbageConsumption(java.math.BigDecimal garbageConsumption) {
        this.garbageConsumption = garbageConsumption;
    }
    /**
     * 其他项目
     */
    public java.math.BigDecimal getOtherItems() {
        return otherItems;
    }

    /**
     * 其他项目
     */
    public void setOtherItems(java.math.BigDecimal otherItems) {
        this.otherItems = otherItems;
    }
    /**
     * 造价占比
     */
    public java.math.BigDecimal getCostPercent() {
        return costPercent;
    }

    /**
     * 造价占比
     */
    public void setCostPercent(java.math.BigDecimal costPercent) {
        this.costPercent = costPercent;
    }
    /**
     * 工程规模
     */
    public java.math.BigDecimal getProjectScale() {
        return projectScale;
    }

    /**
     * 工程规模
     */
    public void setProjectScale(java.math.BigDecimal projectScale) {
        this.projectScale = projectScale;
    }
    /**
     * 单位造价
     */
    public java.math.BigDecimal getUnitCost() {
        return unitCost;
    }

    /**
     * 单位造价
     */
    public void setUnitCost(java.math.BigDecimal unitCost) {
        this.unitCost = unitCost;
    }
    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
}
